@@ -1,27 +1,23 @@
 
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-import tempfile
 import os
+import tempfile
 from functools import partial
 
+import matplotlib.pyplot as plt
+import nibabel
 import numpy as np
+from nose.tools import assert_raises, assert_true, assert_equal
 from scipy import sparse
 
-from nose.tools import assert_raises, assert_true, assert_equal
-
-import matplotlib.pyplot as plt
-
-import nibabel
-
+from nilearn._utils.testing import assert_raises_regex
 from nilearn.image.resampling import coord_transform
-
 from nilearn.plotting.img_plotting import (MNI152TEMPLATE, plot_anat, plot_img,
                                            plot_roi, plot_stat_map, plot_epi,
                                            plot_glass_brain, plot_connectome,
                                            plot_prob_atlas,
                                            _get_colorbar_and_data_ranges)
-from nilearn._utils.testing import assert_raises_regex
 
 mni_affine = np.array([[-2.,    0.,    0.,   90.],
                        [0.,    2.,    0., -126.],
@@ -58,6 +54,9 @@ def test_demo_plot_roi():
     # Test the black background code path
     demo_plot_roi(black_bg=True)
 
+    # Save execution time and memory
+    plt.close()
+
     with tempfile.NamedTemporaryFile(suffix='.png') as fp:
         out = demo_plot_roi(output_file=fp)
     assert_true(out is None)
@@ -88,6 +87,9 @@ def test_plot_anat():
     finally:
         os.remove(filename)
 
+    # Save execution time and memory
+    plt.close()
+
 
 def test_plot_functions():
     img = _generate_img()
@@ -122,6 +124,13 @@ def test_plot_glass_brain():
     # test plot_glass_brain with negative values
     plot_glass_brain(img, colorbar=True, plot_abs=False)
 
+    # Save execution time and memory
+    plt.close()
+    # smoke-test for hemispheric glass brain
+    filename = tempfile.mktemp(suffix='.png')
+    plot_glass_brain(img, output_file=filename, display_mode='lzry')
+    plt.close()
+
 
 def test_plot_stat_map():
     img = _generate_img()
@@ -149,6 +158,9 @@ def test_plot_stat_map():
     new_img = nibabel.Nifti1Image(data, aff)
     plot_stat_map(new_img, threshold=1000, colorbar=True)
 
+    # Save execution time and memory
+    plt.close()
+
 
 def test_plot_stat_map_threshold_for_affine_with_rotation():
     # threshold was not being applied when affine has a rotation
@@ -168,6 +180,9 @@ def test_plot_stat_map_threshold_for_affine_with_rotation():
     # Given the high threshold the array should be entirely masked
     assert_true(plotted_array.mask.all())
 
+    # Save execution time and memory
+    plt.close()
+
 
 def test_plot_stat_map_threshold_for_uint8():
     # mask was applied in [-threshold, threshold] which is problematic
@@ -191,6 +206,9 @@ def test_plot_stat_map_threshold_for_uint8():
     # axis orientation seem to be flipped, hence (0, 0) -> (-1, 0)
     assert_true(plotted_array.mask[-1, 0])
 
+    # Save execution time and memory
+    plt.close()
+
 
 def test_plot_glass_brain_threshold_for_uint8():
     # mask was applied in [-threshold, threshold] which is problematic
@@ -214,6 +232,9 @@ def test_plot_glass_brain_threshold_for_uint8():
     # axis orientation seem to be flipped, hence (0, 0) -> (-1, 0)
     assert_true(plotted_array.mask[-1, 0])
 
+    # Save execution time and memory
+    plt.close()
+
 
 def test_save_plot():
     img = _generate_img()
@@ -235,6 +256,9 @@ def test_save_plot():
         finally:
             os.remove(filename)
 
+        # Save execution time and memory
+        plt.close()
+
 
 def test_display_methods():
     img = _generate_img()
@@ -254,6 +278,9 @@ def test_plot_with_axes_or_figure():
     ax = plt.subplot(111)
     plot_img(img, axes=ax)
 
+    # Save execution time and memory
+    plt.close()
+
 
 def test_plot_stat_map_colorbar_variations():
     # This is only a smoke test
@@ -284,6 +311,9 @@ def test_plot_empty_slice():
     img = nibabel.Nifti1Image(data, mni_affine)
     plot_img(img, display_mode='y', threshold=1)
 
+    # Save execution time and memory
+    plt.close()
+
 
 def test_plot_img_invalid():
     # Check that we get a meaningful error message when we give a wrong
@@ -300,6 +330,9 @@ def test_plot_img_with_auto_cut_coords():
         plot_img(img, cut_coords=None, display_mode=display_mode,
                  black_bg=True)
 
+        # Save execution time and memory
+        plt.close()
+
 
 def test_plot_img_with_resampling():
     data = _generate_img().get_data()
@@ -314,6 +347,9 @@ def test_plot_img_with_resampling():
                          colors=['limegreen', 'yellow'])
     display.add_edges(img, color='c')
 
+    # Save execution time and memory
+    plt.close()
+
 
 def test_plot_noncurrent_axes():
     """Regression test for Issue #450"""
@@ -332,6 +368,9 @@ def test_plot_noncurrent_axes():
         ax_fh = niax.ax.get_figure()
         assert_equal(ax_fh, fh1, 'New axis %s should be in fh1.' % ax_name)
 
+    # Save execution time and memory
+    plt.close()
+
 
 def test_plot_connectome():
     node_color = ['green', 'blue', 'k', 'cyan']
@@ -347,6 +386,7 @@ def test_plot_connectome():
                   title='threshold=0.38',
                   node_size=10, node_color=node_color)
     plot_connectome(*args, **kwargs)
+    plt.close()
 
     # used to speed-up tests for the next plots
     kwargs['display_mode'] = 'x'
@@ -364,6 +404,7 @@ def test_plot_connectome():
                     os.path.getsize(filename) > 0)
     finally:
         os.remove(filename)
+    plt.close()
 
     # with node_kwargs, edge_kwargs and edge_cmap arguments
     plot_connectome(*args,
@@ -371,21 +412,25 @@ def test_plot_connectome():
                     node_size=[10, 20, 30, 40],
                     node_color=np.zeros((4, 3)),
                     edge_cmap='RdBu',
+                    colorbar=True,
                     node_kwargs={
                         'marker': 'v'},
                     edge_kwargs={
                         'linewidth': 4})
+    plt.close()
 
     # masked array support
     masked_adjacency_matrix = np.ma.masked_array(
         adjacency_matrix, np.abs(adjacency_matrix) < 0.5)
     plot_connectome(masked_adjacency_matrix, node_coords,
                     **kwargs)
+    plt.close()
 
     # sparse matrix support
     sparse_adjacency_matrix = sparse.coo_matrix(adjacency_matrix)
     plot_connectome(sparse_adjacency_matrix, node_coords,
                     **kwargs)
+    plt.close()
 
     # NaN matrix support
     nan_adjacency_matrix = np.array([[1., np.nan, 0.],
@@ -393,13 +438,20 @@ def test_plot_connectome():
                                      [np.nan, 2., 1.]])
     nan_node_coords = np.arange(3 * 3).reshape(3, 3)
     plot_connectome(nan_adjacency_matrix, nan_node_coords, **kwargs)
+    plt.close()
 
     # smoke-test where there is no edge to draw, e.g. when
     # edge_threshold is too high
     plot_connectome(*args, edge_threshold=1e12)
+    plt.close()
 
     # with colorbar=True
     plot_connectome(*args, colorbar=True)
+    plt.close()
+
+    # smoke-test with hemispheric saggital cuts
+    plot_connectome(*args, display_mode='lzry')
+    plt.close()
 
 
 def test_plot_connectome_exceptions():
@@ -486,6 +538,7 @@ def test_singleton_ax_dim():
         shape[axis] = 1
         img = nibabel.Nifti1Image(np.ones(shape), np.eye(4))
         plot_stat_map(img, None, display_mode=direction)
+        plt.close()
 
 
 def test_plot_prob_atlas():
@@ -496,11 +549,20 @@ def test_plot_prob_atlas():
     img = nibabel.Nifti1Image(data_rng, affine)
     # Testing the 4D plot prob atlas with contours
     plot_prob_atlas(img, view_type='contours')
+    plt.close()
     # Testing the 4D plot prob atlas with contours
     plot_prob_atlas(img, view_type='filled_contours',
                     threshold=0.2)
+    plt.close()
     # Testing the 4D plot prob atlas with contours
     plot_prob_atlas(img, view_type='continuous')
+    plt.close()
+    # Testing the 4D plot prob atlas with colormap
+    plot_prob_atlas(img, view_type='filled_contours', colorbar=True)
+    plt.close()
+    # threshold=None
+    plot_prob_atlas(img, threshold=None)
+    plt.close()
 
 
 def test_get_colorbar_and_data_ranges_with_vmin():
